@@ -111,10 +111,12 @@ for path in files:
                                     f"Can't proceed"
     # download the file
     # construct path to store the dearchived file
+    logger.info(f"Downloading file to be dearchived: {abs_path}")
     basename = os.path.basename(abs_path)
     downloaded_path = os.path.join(args.directory, basename)
     api.retrieve_object(fireOid=dearch_fobj.fireOid,
                         outfile=downloaded_path)
+    logger.info(f"Download completed!")
 
     if str2bool(args.md5check) is True:
         logger.info("Checking if the md5sum of the retrieved and archived"
@@ -127,4 +129,4 @@ for path in files:
     # delete FIRE object
     api.delete_object(fireOid=dearch_fobj.fireOid, dry=str2bool(args.dry))
     # finally, delete de-archived file from RESEQTRACK DB
-    db.delete_file(dearch_f, dry=str2bool(args.dry))
\ No newline at end of file
+    db.delete_file(dearch_f, dry=str2bool(args.dry))
