@@ -19,14 +19,22 @@ class API(object):
     Class to deal with the queries to the FIRE API for
     archival and retrieval activities
 
-    Class variables
-    ---------------
-    pwd : str, Required
-          Password for API
-    user : str,
-           Username for API. Obtained from settings.ini
+    Attributes
+    ----------
+    pwd : str
+          Password for API.
+    user : str
+           Username for API.
     """
     def __init__(self, pwd):
+        """
+        Constructor
+
+        Parameters
+        ----------
+        pwd : str
+              Password for API.
+        """
 
         api_logger.debug('Creating an API object')
 
@@ -40,13 +48,19 @@ class API(object):
         Parameters
         ----------
         cd : str
-             Content disposition from Requests.headers
+             Content disposition from Requests.headers.
+        
+        Returns
+        -------
+        fname[0] : str
+                   filename
         """
         if not cd:
             return None
         fname = re.findall('filename=(.+)', cd)
         if len(fname) == 0:
             return None
+
         return fname[0]
 
     def retrieve_object(self, fireOid=None, firePath=None, outfile=None):
@@ -55,16 +69,17 @@ class API(object):
 
         Parameters
         ----------
-        fireOid : str
-                  FIRE object id. Optional
-        firePath : str
-                   FIRE path id. Optional
-        outfile : file
-                  Output file name. Optional.
+        fireOid : str, optional
+                  FIRE object id.
+        firePath : str, optional
+                   FIRE path id.
+        outfile : str, optional
+                  Output file name.
 
         Returns
         -------
-        file : Downloaded file
+        outfile : str
+                  Downloaded file
 
         Raises
         ------
@@ -100,6 +115,7 @@ class API(object):
             api_logger.debug('Retrieved object')
 
             return outfile
+
         except HTTPError as http_err:
             print(f'HTTP error occurred: {http_err}')
         except Exception as err:
@@ -112,16 +128,15 @@ class API(object):
 
         Parameters
         ----------
-        fireOid : str
-                  FIRE object id. Optional
-        firePath : str
-                   FIRE virtual path. Optional
+        fireOid : str, optional
+                  FIRE object id.
+        firePath : str, optional
+                   FIRE virtual path.
 
         Returns
         -------
-        fire.object.fObject
-            Object with metadata
-        None if object does not exist in FIRE
+        fireObj : fire.object.fObject
+                  Object with metadata or None.
 
         Raises
         ------
@@ -152,8 +167,6 @@ class API(object):
             print(f'Other error occurred: {err}')
             print(f'Error message: {res.text}')
         else:
-            json_res = res.json()
-
             fireObj = None
             if res.status_code == 404:
                 api_logger.info('No FIRE object found')
@@ -162,8 +175,10 @@ class API(object):
                 api_logger.info('There was an issue in the FIRE API request')
                 raise Exception(f"Error: {res.text}")
             else:
+                json_res = res.json()
                 fireObj = self.__parse_json_response(json_res)
                 api_logger.debug('Fetched FIRE object')
+
                 return fireObj
 
     def __parse_json_response(self, json_res):
@@ -173,12 +188,13 @@ class API(object):
 
         Parameters
         ----------
-        json_res : json response generated
-                   by the Requests library
+        json_res : json response 
+                   generated by the Requests library.
 
         Returns
         -------
-        fire.object
+        fireObj : fire.object.fObject
+                  Object instantiated from json
         """
 
         metadata_dict = {}
@@ -202,22 +218,22 @@ class API(object):
 
         Parameters
         ----------
-        fileO : file.file.File object
-                Object to be uploaded
-        dry : Bool, optional
-              If dry=True then it will not try
-              to push the File object to FIRE. Default True
-        publish : Bool, optional
-                 If publish=True then the pushed object will
-                 be published on upload. Default True
+        fileO : File object
+                Object to be uploaded.
+        dry : bool, default=True
+              If True then it will not try
+              to push the File object to FIRE.
+        publish : bool, default=True
+                 If True then the pushed object will
+                 be published on upload.
         fire_path : str, optional
                     Virtual path in FIRE to be used for
                     pushing this File.
 
         Returns
         -------
-        fire.object.fObject
-                fObject with metadata on the stored FIRE object
+        fire_obj : fire.object.fObject
+                  fObject with metadata on the stored FIRE object.
 
         Raises
         ------
@@ -278,24 +294,21 @@ class API(object):
         
         Parameters
         ----------
-        attr_name : str
-                    Attribute name to modify. Required
-                    Valid attribute names are: 'firePath', 'publish'
+        attr_name : {'firePath', 'publish'}
+                    Attribute name to modify.
         value : str
-                New value for 'attr_name'. Required
-        dry : Bool, optional
-              If dry=True then it will not try
-              to update the archived FIRE object. Default True
-        fireOid : str
+                New value for `attr_name`.
+        dry : bool, default=True
+              If True then it will not try to update the archived FIRE object.
+        fireOid : str, optional
                   FIRE object id that will be modified.
-                  Optional
-        firePath : str
+        firePath : str, optional
                    FIRE virtual path that will be modified.
-                   Optional
 
         Returns
         -------
-        fire.object.fObject with updated 'attr_name'
+        fireObj : fire.object.fObject 
+                  fObject with updated `attr_name`.
 
         Raises
         ------
@@ -362,11 +375,19 @@ class API(object):
 
         Parameters
         ----------
-        fireOid : str
-                  FIRE object id. Optional
-        dry : Bool, optional
-              If dry=True then it will not try
-              to delete the FIRE object. Default True
+        fireOid : str, optional
+                  FIRE object id.
+        dry : bool, default=True
+              If True then it will not try to delete the FIRE object.
+        
+        Returns
+        -------
+        None
+        
+        Raises
+        ------
+        HTTPError 
+        Exception
         """
 
         api_logger.info(f"Deleting FIRE object with fireOid: {fireOid}")
@@ -390,4 +411,4 @@ class API(object):
             api_logger.info(f"FIRE object was not deleted")
             api_logger.info(f"Use --dry False to deleted it")
         else:
-            raise Exception(f"dry option: {dry} not recognized")
+            raise Exception(f"dry option: {dry} not recognized")
\ No newline at end of file
